@@ -17,6 +17,9 @@ class Deployer(object):
         self.docker = docker
         self.local = local
 
+        # Appending the current path to grab any other files.
+        os.sys.path.append(self.dir)
+
     def _get_env_vars(self):
         # Getting environment variables.
         env_vars = []
@@ -33,9 +36,6 @@ class Deployer(object):
         return env_vars
 
     def _build_template(self, output_dir=None):
-        # Appending the current path to grab any other files.
-        os.sys.path.append(self.dir)
-
         # Checking custom output directory.
         output_file = f"{output_dir}/bld.yml" if output_dir else "bld.yml"
 
@@ -81,14 +81,27 @@ class Deployer(object):
         f.close()
 
     def _local_build(self):
-        build_path = f"{self.dir}/.aws-sam/build"
+        build_path = os.path.abspath(f"{self.dir}/.aws-sam/build")
         if os.path.exists(build_path):
             shutil.rmtree(build_path)
 
         os.mkdir(build_path)
+
+        # Install requirements.
         pip_cmd = ["pip", "install", "-r", "requirements.txt", "-t", build_path]
         subprocess.run(pip_cmd, cwd=self.dir)
-        shutil.copy("bld.yml", build_path)
+
+        # Copy template in there.
+        shutil.copyfile("bld.yml", f"{build_path}/template.yml")
+
+        # Copying Python code to build directory.
+        # TODO: Add symlinks for all Python files so live updated works.
+        for (dirpath, dirnames, filenames) in os.walk(self.dir):
+            files = list(filter(lambda x: x.endswith(".py"), filenames))
+            break
+
+        for f in files:
+            shutil.copyfile(os.path.abspath(f"{dirpath}/{f}"), f"{build_path}/{f}")
 
     def _sam_build(self):
         # Run the SAM CLI to build and deploy.
@@ -157,18 +170,20 @@ class Deployer(object):
 
         env_vars = self._get_env_vars()
         overrides = [f"{x['alpha_name']}={x['value']}" for x in env_vars]
-        subprocess.run(
-            [
-                "sam",
-                "local",
-                "start-api",
-                "-d 5858",
-                "--parameter-overrides",
-                ",".join(overrides),
-            ],
-            cwd=self.dir,
-            check=True,
-        )
+        overrides.append("ENVIRONMENT=sam")
+        sam_start = [
+            "sam",
+            "local",
+            "start-api",
+            "-d 5858",
+            "--template-file",
+            ".aws-sam/build/template.yml",
+        ]
+        if len(overrides) > 0:
+            sam_start.append("--parameter-overrides")
+            sam_start.append(",".join(overrides))
+
+        subprocess.run(sam_start, cwd=self.dir, check=True)
 
     def invoke(self, function):
         self._build_template()
